# Amarium

[![License: GPL v3](https://img.shields.io/badge/License-GPL_v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
![Python Versions](https://img.shields.io/badge/python-3.9%20%7C%203.10%20%7C%203.11%20%7C-blue) 
![Style Black](https://warehouse-camo.ingress.cmh1.psfhosted.org/fbfdc7754183ecf079bc71ddeabaf88f6cbc5c00/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f636f64652532307374796c652d626c61636b2d3030303030302e737667) 
[![status-badge](https://ci.codeberg.org/api/badges/cap_jmk/amarium/status.svg)](https://ci.codeberg.org/cap_jmk/amarium)

# Why 
I found myself constantly writing files of some sort always having to face the same problems and writing the same code for it. So I decided at some point to seperate the package out. Up to now, I did not find a good place on PyPi for it. But I should 

# What 

Short program with a collection of functions frequently used in handling the filesystem

# Usage 

Please refer to the `tests/` directory for examples of the functions and their usage 
